@@ -1,3 +1,6 @@
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
@@ -17,7 +20,7 @@ import aws_cdk.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdk-common", "1.0.456", __name__[0:-6], "cdk-common@1.0.456.jsii.tgz"
+    "cdk-common", "1.0.874", __name__[0:-6], "cdk-common@1.0.874.jsii.tgz"
 )
 
 __all__ = [
